aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/graph
diff options
context:
space:
mode:
Diffstat (limited to 'src/jogl/classes/com/jogamp/graph')
-rw-r--r--src/jogl/classes/com/jogamp/graph/curve/opengl/GLRegion.java6
-rw-r--r--src/jogl/classes/com/jogamp/graph/curve/opengl/TextRegionUtil.java19
-rw-r--r--src/jogl/classes/com/jogamp/graph/font/Font.java47
3 files changed, 53 insertions, 19 deletions
diff --git a/src/jogl/classes/com/jogamp/graph/curve/opengl/GLRegion.java b/src/jogl/classes/com/jogamp/graph/curve/opengl/GLRegion.java
index aca5fca52..aa756582a 100644
--- a/src/jogl/classes/com/jogamp/graph/curve/opengl/GLRegion.java
+++ b/src/jogl/classes/com/jogamp/graph/curve/opengl/GLRegion.java
@@ -150,10 +150,10 @@ public abstract class GLRegion extends Region {
region = new VBORegionSPES2(glp, renderModes, colorTexSeq, 0, 0);
}
final int[] vertIndexCount = { 0, 0 };
- final OutlineShape.Visitor2 visitor = new OutlineShape.Visitor2() {
+ final Font.GlyphVisitor2 visitor = new Font.GlyphVisitor2() {
@Override
- public final void visit(final OutlineShape shape) {
- region.countOutlineShape(shape, vertIndexCount);
+ public final void visit(final Font.Glyph glyph) {
+ region.countOutlineShape(glyph.getShape(), vertIndexCount);
} };
font.processString(visitor, str);
region.setBufferCapacity(vertIndexCount[0], vertIndexCount[1]);
diff --git a/src/jogl/classes/com/jogamp/graph/curve/opengl/TextRegionUtil.java b/src/jogl/classes/com/jogamp/graph/curve/opengl/TextRegionUtil.java
index de9ff5636..35b6d5028 100644
--- a/src/jogl/classes/com/jogamp/graph/curve/opengl/TextRegionUtil.java
+++ b/src/jogl/classes/com/jogamp/graph/curve/opengl/TextRegionUtil.java
@@ -37,6 +37,7 @@ import com.jogamp.opengl.math.geom.AABBox;
import com.jogamp.graph.curve.OutlineShape;
import com.jogamp.graph.curve.Region;
import com.jogamp.graph.font.Font;
+import com.jogamp.graph.font.Font.Glyph;
import com.jogamp.graph.geom.plane.AffineTransform;
/**
@@ -106,11 +107,15 @@ public class TextRegionUtil {
public static AABBox addStringToRegion(final Region region, final Font font, final AffineTransform transform,
final CharSequence str, final float[] rgbaColor,
final AffineTransform temp1, final AffineTransform temp2) {
- final OutlineShape.Visitor visitor = new OutlineShape.Visitor() {
+ final Font.GlyphVisitor visitor = new Font.GlyphVisitor() {
@Override
- public final void visit(final OutlineShape shape, final AffineTransform t) {
- region.addOutlineShape(shape, t, region.hasColorChannel() ? rgbaColor : null);
- } };
+ public void visit(final Glyph glyph, final AffineTransform t) {
+ if( glyph.isWhiteSpace() ) {
+ return;
+ }
+ region.addOutlineShape(glyph.getShape(), t, region.hasColorChannel() ? rgbaColor : null);
+ }
+ };
return font.processString(visitor, transform, str, temp1, temp2);
}
@@ -128,10 +133,10 @@ public class TextRegionUtil {
* @see #drawString3D(GL2ES2, GLRegion, RegionRenderer, Font, CharSequence, float[], int[], AffineTransform, AffineTransform)
*/
public static void countStringRegion(final Region region, final Font font, final CharSequence str, final int[/*2*/] vertIndexCount) {
- final OutlineShape.Visitor2 visitor = new OutlineShape.Visitor2() {
+ final Font.GlyphVisitor2 visitor = new Font.GlyphVisitor2() {
@Override
- public final void visit(final OutlineShape shape) {
- region.countOutlineShape(shape, vertIndexCount);
+ public final void visit(final Font.Glyph glyph) {
+ region.countOutlineShape(glyph.getShape(), vertIndexCount);
} };
font.processString(visitor, str);
}
diff --git a/src/jogl/classes/com/jogamp/graph/font/Font.java b/src/jogl/classes/com/jogamp/graph/font/Font.java
index 1b5452a45..2a75a203f 100644
--- a/src/jogl/classes/com/jogamp/graph/font/Font.java
+++ b/src/jogl/classes/com/jogamp/graph/font/Font.java
@@ -172,6 +172,9 @@ public interface Font {
/** Return the glyph's name, source from `post` table */
String getName();
+ /** Return true if the underlying {@link #getShape()} is a whitespace, otherwise false. */
+ boolean isWhiteSpace();
+
/**
* Return the AABBox in font-units, borrowing internal instance.
*/
@@ -246,6 +249,30 @@ public interface Font {
String fullString();
}
+ /**
+ * General purpose {@link Font.Glyph} visitor.
+ */
+ public static interface GlyphVisitor {
+ /**
+ * Visiting the given {@link Font.Glyph} having an {@link OutlineShape} with it's corresponding {@link AffineTransform}.
+ * @param glyph {@link Font.Glyph} which contains an {@link OutlineShape} via {@link Font.Glyph#getShape()}.
+ * @param t may be used immediately as is, otherwise a copy shall be made if stored.
+ */
+ public void visit(final Glyph glyph, final AffineTransform t);
+ }
+
+ /**
+ * Constrained {@link Font.Glyph} visitor w/o {@link AffineTransform}.
+ */
+ public static interface GlyphVisitor2 {
+ /**
+ * Visiting the given {@link Font.Glyph} having an {@link OutlineShape}.
+ * @param glyph {@link Font.Glyph} which contains an {@link OutlineShape} via {@link Font.Glyph#getShape()}.
+ */
+ public void visit(final Glyph glyph);
+ }
+
+
String getName(final int nameIndex);
/** Shall return the family and subfamily name, separated a dash.
@@ -417,39 +444,41 @@ public interface Font {
boolean isPrintableChar(final char c);
/**
- * Try using {@link #processString(com.jogamp.graph.curve.OutlineShape.Visitor, AffineTransform, CharSequence, AffineTransform, AffineTransform)}
+ * Try using {@link #processString(GlyphVisitor, AffineTransform, CharSequence, AffineTransform, AffineTransform)}
* to reuse {@link AffineTransform} instances.
+ * @see #processString(GlyphVisitor, AffineTransform, CharSequence, AffineTransform, AffineTransform)
*/
- AABBox processString(final OutlineShape.Visitor visitor, final AffineTransform transform,
+ AABBox processString(final Font.GlyphVisitor visitor, final AffineTransform transform,
final CharSequence string);
/**
- * Visit each {@link Glyph}'s {@link OutlineShape} of the string with the {@link OutlineShape.Visitor}
+ * Visit each {@link Glyph} and perhaps its {@link OutlineShape} of the string with the {@link Font.GlyphVisitor}
* while passing the progressed {@link AffineTransform}.
* <p>
* The processed shapes are in font em-size [0..1], but can be adjusted with the given transform, progressed and passed to the visitor.
* </p>
- * @param visitor handling each glyph's outline shape in font em-size [0..1] and the given {@link AffineTransform}
- * @param transform optional given transform
+ * @param visitor handling each {@link Font.Glyph} and perhaps its {@link OutlineShape} in font em-size [0..1] and the given {@link AffineTransform}
+ * @param transform optional given transform for size and position
* @param font the target {@link Font}
* @param string string text
* @param temp1 temporary AffineTransform storage, mandatory
* @param temp2 temporary AffineTransform storage, mandatory
* @return the bounding box of the given string by taking each glyph's font em-sized [0..1] {@link OutlineShape} into account.
+ * @see #processString(GlyphVisitor, AffineTransform, CharSequence)
*/
- AABBox processString(final OutlineShape.Visitor visitor, final AffineTransform transform,
+ AABBox processString(final Font.GlyphVisitor visitor, final AffineTransform transform,
final CharSequence string,
final AffineTransform temp1, final AffineTransform temp2);
/**
* Visit each {@link Glyph}'s {@link OutlineShape} of the string with the constrained {@link OutlineShape.Visitor2}.
* <p>
* The processed shapes are in font em-size [0..1].
* </p>
- * @param visitor handling each glyph's outline shape in font em-size [0..1]
+ * @param visitor handling each {@link Font.Glyph} and perhaps its {@link OutlineShape} in font em-size [0..1]
* @param string string text
*/
- void processString(final OutlineShape.Visitor2 visitor, final CharSequence string);
+ void processString(final Font.GlyphVisitor2 visitor, final CharSequence string);
/** Returns {@link #getFullFamilyName()} */
@Override
@@ -417,39 +444,41 @@ public interface Font {
final AffineTransform temp1, final AffineTransform temp2);
/**
- * Visit each {@link Glyph}'s {@link OutlineShape} of the string with the constrained {@link OutlineShape.Visitor2}.
+ * Visit each {@link Glyph} and perhaps its {@link OutlineShape} of the string with the constrained {@link Font.GlyphVisitor2}.
* <p>
* The processed shapes are in font em-size [0..1].